package com.vetti.hotake.service;

import java.util.List;
import com.vetti.hotake.domain.HotakeMeetingCalendarInfo;
import com.vetti.hotake.domain.dto.HotakeMeetingCalendarDataDto;
import com.vetti.hotake.domain.vo.HotakeMeetingCalendarVo;

/**
 * 会议日历记录主Service接口
 * 
 * @author wangxiangshun
 * @date 2025-11-09
 */
public interface IHotakeMeetingCalendarInfoService 
{
    /**
     * 查询会议日历记录主
     * 
     * @param id 会议日历记录主主键
     * @return 会议日历记录主
     */
    public HotakeMeetingCalendarInfo selectHotakeMeetingCalendarInfoById(Long id);

    /**
     * 查询会议日历记录主列表
     * 
     * @param hotakeMeetingCalendarInfo 会议日历记录主
     * @return 会议日历记录主集合
     */
    public List<HotakeMeetingCalendarInfo> selectHotakeMeetingCalendarInfoList(HotakeMeetingCalendarInfo hotakeMeetingCalendarInfo);


    /**
     * 查询会议日历记录主列表
     *
     * @param hotakeMeetingCalendarInfo 会议日历记录主
     * @return 会议日历记录主集合
     */
    public List<HotakeMeetingCalendarInfo> selectHotakeMeetingCalendarInfoCandidateList(HotakeMeetingCalendarInfo hotakeMeetingCalendarInfo);


    /**
     * 新增会议日历记录主
     * 
     * @param hotakeMeetingCalendarInfo 会议日历记录主
     * @return 结果
     */
    public HotakeMeetingCalendarInfo insertHotakeMeetingCalendarInfo(HotakeMeetingCalendarInfo hotakeMeetingCalendarInfo);

    /**
     * 修改会议日历记录主
     * 
     * @param hotakeMeetingCalendarInfo 会议日历记录主
     * @return 结果
     */
    public HotakeMeetingCalendarInfo updateHotakeMeetingCalendarInfo(HotakeMeetingCalendarInfo hotakeMeetingCalendarInfo);

    /**
     * 批量删除会议日历记录主
     * 
     * @param ids 需要删除的会议日历记录主主键集合
     * @return 结果
     */
    public int deleteHotakeMeetingCalendarInfoByIds(Long[] ids);

    /**
     * 删除会议日历记录主信息
     * 
     * @param id 会议日历记录主主键
     * @return 结果
     */
    public int deleteHotakeMeetingCalendarInfoById(Long id);

    /**
     * 批量新增会议日历记录主
     *
     * @param hotakeMeetingCalendarInfoList 会议日历记录主列表
     * @return 结果
     */
    public int batchInsertHotakeMeetingCalendarInfo(List<HotakeMeetingCalendarInfo> hotakeMeetingCalendarInfoList);


    /**
     * 保存会议日历记录
     *
     * @param calendarVo 面试邀请信息
     * @return 结果
     */
    public void saveHotakeMeetingCalendarInfo(HotakeMeetingCalendarVo calendarVo);


    /**
     * 查询当前候选者会议日历数据
     *
     * @return 查询当前候选者会议日历数据
     */
    public List<HotakeMeetingCalendarDataDto> selectHotakeMeetingCalendarDataDtoList();


    /**
     * 获取当前候选人即将开始的会议信息
     *
     * @return 会议日历记录主
     */
    public HotakeMeetingCalendarInfo selectCandidateStartCalendarInfo();

}
